lmw_est fitssummary() computes the treatment effect and potential outcome mean
estimates from the supplied lmw_est object. It functions similarly to
summary.lm() in producing estimate tables with the estimates,
standard errors, t-statistics, and p-values. Other model statistics can be
additionally requested.
# S3 method for lmw_est_aipw
summary(object, model = FALSE, ci = TRUE, alpha = 0.05, ...)# S3 method for lmw_est
summary(object, model = FALSE, ci = TRUE, alpha = 0.05, ...)
A summary.lmw_est object with the following components:
the original call to lmw_est()
a matrix
containing the estimated potential outcome means, their standard errors,
confidence interval limits (if requested with ci = TRUE),
t-statistics, and p-values. Omitted when method = "URI" or
fixef is not NULL and for lmw_iv objects.
a matrix containing the treatment effect estimates and
their standard errors, t-statistics, and p-values.When ci = TRUE, the
confidence limits "95%" CI L (lower) and "95%" CI U (upper)
will be included between the standard error and t-statistic columns. When
AIPW is used, z-statistics and z-tests are reported instead.
when model = TRUE, the coefficient table of
the model coefficients, which has the same columns as coefficients.
when model = TRUE, a named logical vector showing if
the original coefficients are aliased (i.e., NA).
the residual standard deviation, degrees of
freedom components, R-squared, and adjusted R-squared. See
summary.lm(). When AIPW is used, sigma and df are
omitted.
Other components containing information for printing are also included.
an lmw_est object; the output of a call to
lmw_est.
logical; whether to produce a coefficient table for the
outcome model coefficients. Note that these values should not be interpreted
or reported so they are not produced by default.
logical; whether to include confidence intervals in the
output.
when ci = TRUE, the alpha value used to compute the
critical test statistic for the confidence interval; equivalently, 1 minus
the confidence level (e.g., for a 99% confidence interval, alpha = .01 should be specified). Default is .05 for a 95% confidence interval.
ignored.
summary.lmw_est() produces a table of treatment effect estimates
corresponding to all possible pairwise contrasts between the treatment
levels. These treatment effects generalize to the population implied by the
regression weights, which depends on the supplied estimand, whether sampling
weights were provided, and which of the MRI or URI models was requested. The
treatment effects are computed using linear contrasts of the outcome model
coefficients.
When method = "MRI", the potential outcome mean estimates are also
reported. These correspond to the potential outcome means in the population
implied by the regression weights. When method = "URI", only the
treatment effects are estimated; the model-implied outcome means do not
correspond to the potential outcome means for the population implied by the
regression weights. That is, while the treatment effect generalizes to the
population defined by the regression weights, the estimated potential
outcome means do not and so are not reported.
When model = TRUE, the model coefficients and their tests statistics
are additionally produced. It is inappropriate to interpret or report these
values as they have no causal interpretation. This is especially true when
using AIPW, as the model coefficients do not incorporate the augmentation
terms.
lmw_est() for fitting the outcome regression model,
summary.lm() for more information on the output components
# See examples at `help("lmw_est")`
Run the code above in your browser using DataLab